==> haskell-vector-instances-3.4.3-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-instances
version:              3.4.3
visibility:           public
id:                   vector-instances-3.4.3-L5dcRrH9qnxKCaxebjclid
key:                  vector-instances-3.4.3-L5dcRrH9qnxKCaxebjclid
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
description:          Orphan Instances for '\''Data.Vector'\''.
category:             Data, Data Structures
abi:                  5c548c45ee00e4397beacbefcea1e652
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-instances
hs-libraries:         HSvector-instances-3.4.3-L5dcRrH9qnxKCaxebjclid
depends:
    base-4.17.2.1 comonad-5.0.9-WdRIGdTjRI2TeSrvZ2o2
    hashable-1.4.4.0-Bi9h4Si3Ui62sqHmMmGfiv
    keys-3.12.4-1iwmktwOtPB2d9G0YBfDFq
    pointed-5.0.5-D14dmqCabKeHuhJVA6GeB4
    semigroupoids-6.0.1-ArTD9Cr9btFACC9w7rlHRP
    vector-0.13.2.0-GTax7SJDHXyLP8P6Lzhygl

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-instances-3.4.3-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vector-instances
version:              3.4.3
visibility:           public
id:                   vector-instances-3.4.3-Cd9w0AnYPYRKzdyQ90gQUY
key:                  vector-instances-3.4.3-Cd9w0AnYPYRKzdyQ90gQUY
license:              BSD-3-Clause
maintainer:           ekmett@gmail.com
author:               Edward Kmett
homepage:             http://github.com/ekmett/vector-instances
synopsis:             Orphan Instances for '\''Data.Vector'\''
description:          Orphan Instances for '\''Data.Vector'\''.
category:             Data, Data Structures
abi:                  6cac6279b2ef244909aa5b006b8ac2b2
exposed:              True
exposed-modules:      Data.Vector.Instances
import-dirs:          /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vector-instances-3.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-instances
hs-libraries:         HSvector-instances-3.4.3-Cd9w0AnYPYRKzdyQ90gQUY
depends:
    base-4.17.2.1 comonad-5.0.9-I2bM6t8c2fB7rHIs9XjGyy
    hashable-1.4.4.0-85lkkmOSRZHDIzkr9EkKNp
    keys-3.12.4-46cK4tChi6J2DnBsvK8Cmf
    pointed-5.0.5-DVoNzfeM0Gh9dq0MH5GPnN
    semigroupoids-6.0.1-HojjKCFNEldAzPbwF6sStW
    vector-0.13.2.0-3jopdCx3MMLHVSrvHoDH9i

haddock-interfaces:
    /usr/share/doc/haskell-vector-instances/html/vector-instances.haddock

haddock-html:         /usr/share/doc/haskell-vector-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
